@@ -4,7 +4,7 @@
 modname = 'rememberme'
 distname = 'cubicweb-rememberme'
 
-numversion = (0, 2, 3)
+numversion = (1, 0, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -14,7 +14,14 @@ author_email = 'contact@logilab.fr'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
 
-__depends__ = {'cubicweb': '>= 3.13.7'}
+__depends__ = {'cubicweb': '>= 3.19.4'}
+
+classifiers = [
+    'Environment :: Web Environment',
+    'Framework :: CubicWeb',
+    'Programming Language :: Python',
+    'Programming Language :: Python :: 2',
+    ]
 
 
 # packaging ###
