@@ -12,20 +12,20 @@ from cubicweb.server.sources import native
 
 class AuthCookieAuthentifier(native.BaseAuthentifier):
     auth_rql = ('Any X,AC WHERE X is CWUser, X login %(login)s, '
-                'AC auth_cookie_for_user X, AC magicnumber %(magicnumber)s, '
+                'AC auth_cookie_for_user X, AC magic %(magic)s, '
                 'AC lifetime L, AC creation_date > (NOW - L)')
 
-    def authenticate(self, session, login, magicnumber=None, **kwargs):
-        """return CWUser eid for the given login/magicnumber if this account is
+    def authenticate(self, session, login, magic=None, **kwargs):
+        """return CWUser eid for the given login/cookie if this account is
         defined in this source, else raise `AuthenticationError`
         """
-        if magicnumber is None:
+        if magic is None:
             raise AuthenticationError()
         rset = session.execute(self.auth_rql, {'login': login,
-                                               'magicnumber': magicnumber})
+                                               'magic': magic})
         if rset:
             session.repo.glob_delete_entities(session, set((rset[0][1],)))
             session.commit(free_cnxset=False)
             return rset[0][0]
-        raise AuthenticationError('bad password')
+        raise AuthenticationError('bad cookie')
 
