@@ -20,12 +20,9 @@ class ServerStartupHook(hook.Hook):
         # XXX use named args and inner functions to avoid referencing globals
         # which may cause reloading pb
         def cleanup_auth_cookies(repo=self.repo):
-            session = repo.internal_session()
-            try:
-                session.execute('DELETE CWAuthCookie X WHERE X lifetime L, '
-                                'X creation_date < (NOW - L)')
-                session.commit()
-            finally:
-                session.close()
+            with repo.internal_cnx() as cnx:
+                cnx.execute('DELETE CWAuthCookie X WHERE X lifetime L, '
+                            'X creation_date < (NOW - L)')
+                cnx.commit()
         self.repo.looping_task(60*60, cleanup_auth_cookies, self.repo)
         self.repo.system_source.add_authentifier(AuthCookieAuthentifier())
