@@ -6,7 +6,7 @@
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 :license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 """
-from yams.buildobjs import EntityType, RelationDefinition, Int, Interval
+from yams.buildobjs import EntityType, RelationDefinition, String, Interval
 from cubicweb.schema import ERQLExpression, RRQLExpression
 
 
@@ -18,7 +18,8 @@ class CWAuthCookie(EntityType):
         'delete': ('managers', 'owners'),
         }
 
-    magicnumber = Int()
+    magic = String(required=True, maxsize=128, unique=True,
+                   description=_('unique identifier for the user'))
     lifetime = Interval()
 
 
