@@ -1,17 +1,18 @@
-"""rememberme components: plug authentication retreiver
+"""rememberme components: plug authentication retriever
 
 :organization: Logilab
-:copyright: 2009-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:copyright: 2009-2012 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 :license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 """
 from datetime import date, timedelta
-from random import randint
 
-from cubicweb.selectors import is_instance
-from cubicweb.web import uicfg, formfields as ff, formwidgets as fw
+from cubicweb import Unauthorized
+from cubicweb.utils import make_uid
+from cubicweb.predicates import is_instance
+from cubicweb.web import formfields as ff, formwidgets as fw
 from cubicweb.web.views import (authentication, basecontrollers, basetemplates,
-                                autoform, actions)
+                                autoform, actions, uicfg)
 
 _pvs = uicfg.primaryview_section
 _pvs.tag_object_of(('CWAuthCookie', 'auth_cookie_for_user', 'CWUser'), 'hidden')
@@ -19,12 +20,10 @@ _pvs.tag_object_of(('CWAuthCookie', 'auth_cookie_for_user', 'CWUser'), 'hidden')
 _abaa = uicfg.actionbox_appearsin_addmenu
 _abaa.tag_object_of(('CWAuthCookie', 'auth_cookie_for_user', 'CWUser'), False)
 
-MAX_MAGIC_NUMBER = (2 ** 31) - 1 # XXX ** 128
+# web authentication info retriever ############################################
 
-# web authentication info retreiver ############################################
-
-class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
-    """authenticate by a magic number stored a cookie on the client host
+class AuthCookieRetriever(authentication.WebAuthInfoRetriever):
+    """authenticate by a magic identifier stored a cookie on the client host
     """
     __regid__ = 'magicnumauth'
     order = 0
@@ -34,14 +33,14 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
         self.cookie_lifetime = timedelta(days=30)
 
     def authentication_information(self, req):
-        """retreive authentication information from the given request, raise
+        """retrieve authentication information from the given request, raise
         NoAuthInfo if expected information is not found:
 
         return info from long lived authentication cookie if any
         """
         cookie = req.get_cookie()
         try:
-            authcookie = cookie['__cw_auth_cookie'].value
+            authcookie = cookie['__cw_auth_cookie'].value.decode('ascii')
         except KeyError:
             raise authentication.NoAuthInfo()
         try:
@@ -49,38 +48,39 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
         except ValueError:
             req.remove_cookie('__cw_auth_cookie')
             raise authentication.NoAuthInfo()
-        return login, {'magicnumber': magic}
+        return login, {'magic': magic}
 
     def cleanup_authentication_information(self, req):
         cookie = req.get_cookie()
         req.remove_cookie('__cw_auth_cookie')
 
-    def authenticated(self, retreiver, req, cnx, login, authinfo):
+    def authenticated(self, retriever, req, session, login, authinfo):
         """callback when return authentication information have opened a
         repository connection successfully. Take care req has no session
         attached yet, hence req.execute isn't available.
 
         Here we set authentication cookie for the next time
         """
-        if not (retreiver is self or '__setauthcookie' in req.form):
+        if not (retriever is self or '__setauthcookie' in req.form):
             return
         req.form.pop('__setauthcookie', None)
-        user = cnx.user()
+        user = session.user
         cls = req.vreg['etypes'].etype_class('CWAuthCookie')
         #  req has no session set yet
-        authentity = cls.cw_instantiate(cnx.cursor().execute,
-                                        magicnumber=randint(0, MAX_MAGIC_NUMBER),
-                                        lifetime=self.cookie_lifetime,
-                                        auth_cookie_for_user=user.eid)
+        with session.new_cnx() as cnx:
+            authentity = cls.cw_instantiate(cnx.execute,
+                                            magic=unicode(make_uid()),
+                                            lifetime=self.cookie_lifetime,
+                                            auth_cookie_for_user=user.eid)
+            cnx.commit()
         # we've to commit here, else cookie may be rollbacked by errors while
         # trying to set last_login_time in the CookieSessionHandler (eg for ldap
         # user at least).
-        cnx.commit()
-        magicnum = authentity.magicnumber
-        value = '%s|__magic=%s' % (user.login, magicnum)
+        magic = authentity.magic
+        value = '%s|__magic=%s' % (user.login, magic)
         req.set_cookie('__cw_auth_cookie', value, maxage=None,
                        expires=date.today() + self.cookie_lifetime)
-        authinfo['magicnumber'] = magicnum
+        authinfo['magic'] = magic
 
     def request_has_auth_info(self, req):
         cookie = req.get_cookie()
@@ -89,10 +89,13 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
         except KeyError:
             return False
         try:
-            authcookie.split('|__magic=', 1)
+            login, magicnum = authcookie.split('|__magic=', 1)
         except ValueError:
             req.remove_cookie('__cw_auth_cookie')
             return False
+        if not (login and magicnum):
+            req.remove_cookie('__cw_auth_cookie')
+            return False
         return True
 
     def revalidate_login(self, req):
@@ -104,8 +107,8 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
 # add remember me checkbox on the login form ###################################
 
 basetemplates.LogForm.append_field(
-    ff.BooleanField(name='__setauthcookie', choices=[(_('remember me'), u'1')],
-                    label=None, widget=fw.CheckBox({'class': 'data'}))
+    ff.BooleanField(name='__setauthcookie', choices=[(u'', u'1')],
+                    label=_('remember me'), widget=fw.CheckBox({'class': 'data'}))
     )
 
 
